@@ -3,9 +3,8 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Combinatorial algorithms to generate rhythms
 
-our $VERSION = '0.0802';
+our $VERSION = '0.0803';
 
-use Moo;
 use strictures 2;
 use Algorithm::Combinatorics qw(permutations);
 use Data::Munge qw(list2re);
@@ -13,12 +12,14 @@ use Integer::Partition ();
 use List::Util qw(all any);
 use Math::Sequence::DeBruijn qw(debruijn);
 use Module::Load::Conditional qw(check_install);
+use Moo;
 use Music::AtonalUtil ();
-use namespace::clean;
 
 use if defined check_install(module => 'Math::NumSeq::SqrtContinued'),
     'Math::NumSeq::SqrtContinued';
 
+use namespace::clean;
+
 
 has verbose => (
     is      => 'ro',
@@ -265,33 +266,39 @@ sub comprnd {
 }
 
 
-sub count_ones {
-    my ($self, $n) = @_;
+sub count_digits {
+    my ($self, $digit, $n) = @_;
     my $x = 0;
     if (ref $n) {
         for my $i (@$n) {
-            $x++ if $i == 1;
+            $x++ if $i == $digit;
         }
     }
     else {
-        $x = $n =~ tr/1//;
+           if ($digit == 0) { $x = $n =~ tr/0// }
+        elsif ($digit == 1) { $x = $n =~ tr/1// }
+        elsif ($digit == 2) { $x = $n =~ tr/2// }
+        elsif ($digit == 3) { $x = $n =~ tr/3// }
+        elsif ($digit == 4) { $x = $n =~ tr/4// }
+        elsif ($digit == 5) { $x = $n =~ tr/5// }
+        elsif ($digit == 6) { $x = $n =~ tr/6// }
+        elsif ($digit == 7) { $x = $n =~ tr/7// }
+        elsif ($digit == 8) { $x = $n =~ tr/8// }
+        elsif ($digit == 9) { $x = $n =~ tr/9// }
     }
     return $x;
 }
 
 
+sub count_ones {
+    my ($self, $n) = @_;
+    return $self->count_digits(1, $n);
+}
+
+
 sub count_zeros {
     my ($self, $n) = @_;
-    my $x = 0;
-    if (ref $n) {
-        for my $i (@$n) {
-            $x++ if $i == 0;
-        }
-    }
-    else {
-        $x = $n =~ tr/0//;
-    }
-    return $x;
+    return $self->count_digits(0, $n);
 }
 
 
@@ -602,7 +609,7 @@ Music::CreatingRhythms - Combinatorial algorithms to generate rhythms
 
 =head1 VERSION
 
-version 0.0802
+version 0.0803
 
 =head1 SYNOPSIS
 
@@ -612,15 +619,15 @@ version 0.0802
 
 =head1 DESCRIPTION
 
-C<Music::CreatingRhythms> provides the combinatorial algorithms
-described in the book, "Creating Rhythms", by Hollos. Many of these
-algorithms are ported directly from the C, and are pretty fast. Please
-see the links below for more information.
+C<Music::CreatingRhythms> provides most of the the combinatorial
+algorithms described in the book, "Creating Rhythms", by Hollos. Many
+of these algorithms are ported directly from the C, and are pretty
+fast. Please see the links below for more information.
 
 NB: Arguments are sometimes switched between book and software.
 
 Additionally, this module provides utilities that are not part of the
-book, but are nonetheless handy.
+book but are handy nonetheless.
 
 =head1 ATTRIBUTES
 
@@ -670,6 +677,9 @@ Examples:
 Calculate the continued fraction for C<sqrt(n)> to B<m> digits, where
 B<n> and B<m> are integers.
 
+* This method needs L<Math::NumSeq::SqrtContinued> to be installed.
+YMMV
+
 Examples:
 
   $got = $mcr->cfsqrt(2, 2); # [1,2]
@@ -772,6 +782,19 @@ Example:
 
   $got = $mcr->comprnd(16); # [1,3,2,1,1,2,1,3,2], etc.
 
+=head2 count_digits
+
+  $count = $mcr->count_digits($digit, $n);
+
+Count the number of a given B<digit> in a string or vector (B<n>).
+
+Examples:
+
+  $got = $mcr->count_digits(0, '100110100');         # 5
+  $got = $mcr->count_digits(0, [1,0,0,1,1,0,1,0,0]); # 5
+  $got = $mcr->count_digits(1, '100110100');         # 4
+  $got = $mcr->count_digits(1, [1,0,0,1,1,0,1,0,0]); # 4
+
 =head2 count_ones
 
   $count = $mcr->count_ones($n);
@@ -858,7 +881,7 @@ Example:
   $necklaces = $mcr->necka($n, @intervals);
 
 Generate binary necklaces of length B<n> with allowed intervals
-B<p1, p2, ... pn>. For these "necklace" class of functions, the word
+B<p1, p2, ... pn>. For these "necklace" class of methods, the word
 "intervals" refers to the size of a number given trailing zeros. So
 intervals C<1>, C<2>, and C<3> are represented as C<1>, C<1,0>, and
 C<1,0,0> respectively.
